==> sprout-commonjs-lib-0.6.2.tgz: package/root/readme.md <==
# <%= package_name %>
> <%= package_description %>

[![Build Status](http://img.shields.io/travis/<%= github_user_name %>/<%= repo_name %>.svg)](https://travis-ci.org/<%= github_user_name %>/<%= repo_name %>) [![Code Climate](https://codeclimate.com/github/<%= github_user_name %>/<%= repo_name %>/badges/gpa.svg)](https://codeclimate.com/github/<%= github_user_name %>/<%= repo_name %>) [![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg?style=flat)](https://github.com/feross/standard)

```shell
npm install <%= package_name %> --save
```

###### npm stats

[![npm](https://img.shields.io/npm/v/<%= package_name %>.svg)](https://www.npmjs.org/package/<%= package_name %>) [![NPM downloads](http://img.shields.io/npm/dm/<%= package_name %>.svg)](https://www.npmjs.org/package/<%= package_name %>) [![Dependency Status](https://gemnasium.com/<%= github_user_name %>/<%= repo_name %>.svg)](https://gemnasium.com/<%= github_user_name %>/<%= repo_name %>)

## API Example

```js
var <%= export_name %> = require('<%= package_name %>');
<%= export_name %>('training')
//=> training
```

## Features

 - Supports …

## Anti-Features

 - Will never …

## API

### `<%= export_name %>(string)`

###### arguments

 - `string: (…String)` String Literal.

###### returns

 - `(String)` New String.

## Reference

 - []()

## Alternatives

 - [example](https://example.com)

## Contributing

> SEE: [contributing.md](contributing.md)

## Licenses

[![GitHub license](https://img.shields.io/github/license/<%= github_user_name %>/<%= repo_name %>.svg)]()

==> sprout-commonjs-lib-0.7.7.tgz: package/root/readme.md <==
# <%= package_name %>
> <%= package_description %>

[![Build Status](http://img.shields.io/travis/<%= github_user_name %>/<%= repo_name %>.svg)](https://travis-ci.org/<%= github_user_name %>/<%= repo_name %>) [![Code Climate](https://codeclimate.com/github/<%= github_user_name %>/<%= repo_name %>/badges/gpa.svg)](https://codeclimate.com/github/<%= github_user_name %>/<%= repo_name %>) [![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg?style=flat)](https://github.com/feross/standard)

```shell
npm install <%= package_name %> --save
```

###### npm stats

[![npm](https://img.shields.io/npm/v/<%= package_name %>.svg)](https://www.npmjs.org/package/<%= package_name %>) [![NPM downloads](http://img.shields.io/npm/dm/<%= package_name %>.svg)](https://www.npmjs.org/package/<%= package_name %>) [![Dependency Status](https://gemnasium.com/<%= github_user_name %>/<%= repo_name %>.svg)](https://gemnasium.com/<%= github_user_name %>/<%= repo_name %>)

## API Example

```js
var <%= export_name %> = require('<%= package_name %>')
<%= export_name %>('training')
//=> training
```

## Features

 - Supports …

## Anti-Features

 - Will never …

## API

### `<%= export_name %>(string)`

###### arguments

 - `string: (…String)` String Literal.

###### returns

 - `(String)` New String.

## Reference

 - []()

## Alternatives

 - [example](https://example.com)

## Contributing

> SEE: [contributing.md](contributing.md)

## Licenses

[![GitHub license](https://img.shields.io/github/license/<%= github_user_name %>/<%= repo_name %>.svg)](https://github.com/<%= github_user_name %>/<%= repo_name %>/blob/master/license)
